==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/WuduModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.WuduAnimation;
import net.invictusslayer.slayersbeasts.world.entity.Wudu;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class WuduModel<T extends Wudu> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "wudu_model"), "main");
	private final class_630 root;

	public WuduModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_48741(WuduAnimation.CRAWL, limbSwing, limbSwingAmount, 5, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-8.0F, -16.0F, -8.0F, 16.0F, 16.0F, 16.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 arm_left = body.method_32117("arm_left", class_5606.method_32108().method_32101(48, 8).method_32098(-2.0F, -2.0F, -2.0F, 20.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(8.0F, -11.0F, -1.0F, 0.0F, -0.6981F, 0.5236F));

		class_5610 forearm_left = arm_left.method_32117("forearm_left", class_5606.method_32108().method_32101(31, 38).method_32098(-3.0F, -3.0F, -16.0F, 6.0F, 6.0F, 19.0F, new class_5605(0.0F)), class_5603.method_32091(18.0F, 0.0F, 0.0F, 0.0F, 0.6981F, 0.0873F));

		class_5610 hand_left = forearm_left.method_32117("hand_left", class_5606.method_32108().method_32101(62, 19).method_32098(-4.0F, -1.0F, -13.0F, 8.0F, 8.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -3.0F, -16.0F, 0.0F, 0.0F, -0.3491F));

		class_5610 fl_01 = hand_left.method_32117("fl_01", class_5606.method_32108().method_32101(29, 63).method_32098(-5.0F, -1.5F, -1.5F, 8.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 4.0F, -10.0F, -0.3491F, -0.9599F, 0.0F));

		class_5610 fl_02 = fl_01.method_32117("fl_02", class_5606.method_32108().method_32101(0, 36).method_32098(-6.0F, -1.0F, -1.0F, 7.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-5.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.3491F));

		class_5610 fl_03 = fl_02.method_32117("fl_03", class_5606.method_32108().method_32101(91, 19).method_32098(-7.0F, -1.5F, -1.5F, 7.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(-5.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.3054F));

		class_5610 fl_11 = hand_left.method_32117("fl_11", class_5606.method_32108().method_32101(90, 40).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 2.0F, -13.0F, -0.0873F, 0.1745F, 0.0F));

		class_5610 fl_12 = fl_11.method_32117("fl_12", class_5606.method_32108().method_32101(0, 89).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_13 = fl_12.method_32117("fl_13", class_5606.method_32108().method_32101(64, 88).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_21 = hand_left.method_32117("fl_21", class_5606.method_32108().method_32101(28, 85).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -13.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 fl_22 = fl_21.method_32117("fl_22", class_5606.method_32108().method_32101(50, 85).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_23 = fl_22.method_32117("fl_23", class_5606.method_32108().method_32101(88, 8).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_31 = hand_left.method_32117("fl_31", class_5606.method_32108().method_32101(14, 81).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 2.0F, -13.0F, -0.0873F, -0.1745F, 0.0F));

		class_5610 fl_32 = fl_31.method_32117("fl_32", class_5606.method_32108().method_32101(78, 54).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_33 = fl_32.method_32117("fl_33", class_5606.method_32108().method_32101(84, 80).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 arm_right = body.method_32117("arm_right", class_5606.method_32108().method_32101(48, 0).method_32098(-18.0F, -2.0F, -2.0F, 20.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-8.0F, -11.0F, -1.0F, 0.0F, 0.6981F, -0.5236F));

		class_5610 forearm_right = arm_right.method_32117("forearm_right", class_5606.method_32108().method_32101(0, 32).method_32098(-3.0F, -3.0F, -16.0F, 6.0F, 6.0F, 19.0F, new class_5605(0.0F)), class_5603.method_32091(-18.0F, 0.0F, 0.0F, 0.0F, -0.6981F, -0.0873F));

		class_5610 hand_right = forearm_right.method_32117("hand_right", class_5606.method_32108().method_32101(0, 57).method_32098(-4.0F, -1.0F, -13.0F, 8.0F, 8.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -3.0F, -16.0F, 0.0F, 0.0F, 0.3491F));

		class_5610 fr_01 = hand_right.method_32117("fr_01", class_5606.method_32108().method_32101(31, 32).method_32098(-3.0F, -1.5F, -1.5F, 8.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 4.0F, -10.0F, -0.3491F, 0.9599F, 0.0F));

		class_5610 fr_02 = fr_01.method_32117("fr_02", class_5606.method_32108().method_32101(0, 32).method_32098(-1.0F, -1.0F, -1.0F, 7.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(5.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.3491F));

		class_5610 fr_03 = fr_02.method_32117("fr_03", class_5606.method_32108(), class_5603.method_32090(5.0F, 0.0F, 0.0F));

		class_5610 cube_r1 = fr_03.method_32117("cube_r1", class_5606.method_32108().method_32101(90, 65).method_32098(0.0F, -1.5F, -1.5F, 7.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.3054F));

		class_5610 fr_11 = hand_right.method_32117("fr_11", class_5606.method_32108().method_32101(62, 40).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 2.0F, -13.0F, -0.0873F, -0.1745F, 0.0F));

		class_5610 fr_12 = fr_11.method_32117("fr_12", class_5606.method_32108().method_32101(42, 63).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_13 = fr_12.method_32117("fr_13", class_5606.method_32108().method_32101(64, 63).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_21 = hand_right.method_32117("fr_21", class_5606.method_32108().method_32101(34, 74).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -13.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 fr_22 = fr_21.method_32117("fr_22", class_5606.method_32108().method_32101(56, 74).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_23 = fr_22.method_32117("fr_23", class_5606.method_32108().method_32101(76, 43).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_31 = hand_right.method_32117("fr_31", class_5606.method_32108().method_32101(70, 77).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 2.0F, -13.0F, -0.0873F, 0.1745F, 0.0F));

		class_5610 fr_32 = fr_31.method_32117("fr_32", class_5606.method_32108().method_32101(77, 65).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_33 = fr_32.method_32117("fr_33", class_5606.method_32108().method_32101(0, 78).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/WuduModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.WuduAnimation;
import net.invictusslayer.slayersbeasts.client.state.EntRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class WuduModel extends class_583<EntRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "wudu_model"), "main");

	public WuduModel(class_630 root) {
		super(root);
	}

	public void setupAnim(EntRenderState state) {
		super.method_2819(state);
		method_62102(WuduAnimation.CRAWL, state.field_53450, state.field_53451, 5, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-8.0F, -16.0F, -8.0F, 16.0F, 16.0F, 16.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 arm_left = body.method_32117("arm_left", class_5606.method_32108().method_32101(48, 8).method_32098(-2.0F, -2.0F, -2.0F, 20.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(8.0F, -11.0F, -1.0F, 0.0F, -0.6981F, 0.5236F));

		class_5610 forearm_left = arm_left.method_32117("forearm_left", class_5606.method_32108().method_32101(31, 38).method_32098(-3.0F, -3.0F, -16.0F, 6.0F, 6.0F, 19.0F, new class_5605(0.0F)), class_5603.method_32091(18.0F, 0.0F, 0.0F, 0.0F, 0.6981F, 0.0873F));

		class_5610 hand_left = forearm_left.method_32117("hand_left", class_5606.method_32108().method_32101(62, 19).method_32098(-4.0F, -1.0F, -13.0F, 8.0F, 8.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -3.0F, -16.0F, 0.0F, 0.0F, -0.3491F));

		class_5610 fl_01 = hand_left.method_32117("fl_01", class_5606.method_32108().method_32101(29, 63).method_32098(-5.0F, -1.5F, -1.5F, 8.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 4.0F, -10.0F, -0.3491F, -0.9599F, 0.0F));

		class_5610 fl_02 = fl_01.method_32117("fl_02", class_5606.method_32108().method_32101(0, 36).method_32098(-6.0F, -1.0F, -1.0F, 7.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-5.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.3491F));

		class_5610 fl_03 = fl_02.method_32117("fl_03", class_5606.method_32108().method_32101(91, 19).method_32098(-7.0F, -1.5F, -1.5F, 7.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(-5.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.3054F));

		class_5610 fl_11 = hand_left.method_32117("fl_11", class_5606.method_32108().method_32101(90, 40).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 2.0F, -13.0F, -0.0873F, 0.1745F, 0.0F));

		class_5610 fl_12 = fl_11.method_32117("fl_12", class_5606.method_32108().method_32101(0, 89).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_13 = fl_12.method_32117("fl_13", class_5606.method_32108().method_32101(64, 88).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_21 = hand_left.method_32117("fl_21", class_5606.method_32108().method_32101(28, 85).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -13.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 fl_22 = fl_21.method_32117("fl_22", class_5606.method_32108().method_32101(50, 85).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_23 = fl_22.method_32117("fl_23", class_5606.method_32108().method_32101(88, 8).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_31 = hand_left.method_32117("fl_31", class_5606.method_32108().method_32101(14, 81).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 2.0F, -13.0F, -0.0873F, -0.1745F, 0.0F));

		class_5610 fl_32 = fl_31.method_32117("fl_32", class_5606.method_32108().method_32101(78, 54).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fl_33 = fl_32.method_32117("fl_33", class_5606.method_32108().method_32101(84, 80).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 arm_right = body.method_32117("arm_right", class_5606.method_32108().method_32101(48, 0).method_32098(-18.0F, -2.0F, -2.0F, 20.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-8.0F, -11.0F, -1.0F, 0.0F, 0.6981F, -0.5236F));

		class_5610 forearm_right = arm_right.method_32117("forearm_right", class_5606.method_32108().method_32101(0, 32).method_32098(-3.0F, -3.0F, -16.0F, 6.0F, 6.0F, 19.0F, new class_5605(0.0F)), class_5603.method_32091(-18.0F, 0.0F, 0.0F, 0.0F, -0.6981F, -0.0873F));

		class_5610 hand_right = forearm_right.method_32117("hand_right", class_5606.method_32108().method_32101(0, 57).method_32098(-4.0F, -1.0F, -13.0F, 8.0F, 8.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -3.0F, -16.0F, 0.0F, 0.0F, 0.3491F));

		class_5610 fr_01 = hand_right.method_32117("fr_01", class_5606.method_32108().method_32101(31, 32).method_32098(-3.0F, -1.5F, -1.5F, 8.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 4.0F, -10.0F, -0.3491F, 0.9599F, 0.0F));

		class_5610 fr_02 = fr_01.method_32117("fr_02", class_5606.method_32108().method_32101(0, 32).method_32098(-1.0F, -1.0F, -1.0F, 7.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(5.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.3491F));

		class_5610 fr_03 = fr_02.method_32117("fr_03", class_5606.method_32108(), class_5603.method_32090(5.0F, 0.0F, 0.0F));

		class_5610 cube_r1 = fr_03.method_32117("cube_r1", class_5606.method_32108().method_32101(90, 65).method_32098(0.0F, -1.5F, -1.5F, 7.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.3054F));

		class_5610 fr_11 = hand_right.method_32117("fr_11", class_5606.method_32108().method_32101(62, 40).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 2.0F, -13.0F, -0.0873F, -0.1745F, 0.0F));

		class_5610 fr_12 = fr_11.method_32117("fr_12", class_5606.method_32108().method_32101(42, 63).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_13 = fr_12.method_32117("fr_13", class_5606.method_32108().method_32101(64, 63).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_21 = hand_right.method_32117("fr_21", class_5606.method_32108().method_32101(34, 74).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -13.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 fr_22 = fr_21.method_32117("fr_22", class_5606.method_32108().method_32101(56, 74).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_23 = fr_22.method_32117("fr_23", class_5606.method_32108().method_32101(76, 43).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_31 = hand_right.method_32117("fr_31", class_5606.method_32108().method_32101(70, 77).method_32098(-1.5F, -1.5F, -6.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 2.0F, -13.0F, -0.0873F, 0.1745F, 0.0F));

		class_5610 fr_32 = fr_31.method_32117("fr_32", class_5606.method_32108().method_32101(77, 65).method_32098(-1.0F, -1.0F, -9.0F, 2.0F, 2.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -5.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 fr_33 = fr_32.method_32117("fr_33", class_5606.method_32108().method_32101(0, 78).method_32098(-1.5F, -1.5F, -7.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -9.0F, 0.3491F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}
